// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:flutter/services.dart';

final MethodChannel _globalChannel =
    MethodChannel('plugins.flutter.io/mapmyindia_gl');

/// Copy tiles db file passed in to the tiles cache directory (sideloaded) to
/// make tiles available offline.
Future<void> installOfflineMapTiles(String tilesDb) async {
  await _globalChannel.invokeMethod(
    'installOfflineMapTiles',
    <String, dynamic>{
      'tilesdb': tilesDb,
    },
  );
}

Future<void> setShowLastSelectedStyle(bool showLastSelectedStyle) async {
  await _globalChannel.invokeMethod(
    'setShowLastSelectedStyle',
    <String, dynamic>{
      'showLastSelectedStyle': showLastSelectedStyle,
    },
  );
}

Future<bool> isShowLastSelectedStyle() async {
  return await _globalChannel.invokeMethod("isShowLastSelectedStyle");
}

Future<void> setDeveloperShowingSplash(bool developerShowingSplash) async {
  await _globalChannel.invokeMethod(
    'setDeveloperShowingSplash',
    <String, dynamic>{
      'developerShowingSplash': developerShowingSplash,
    },
  );
}

Future<bool> isDeveloperShowingSplash() async {
  return await _globalChannel.invokeMethod("isDeveloperShowingSplash");
}

Future<void> setClusterId(String? clusterId) async {
  await _globalChannel.invokeMethod(
    'setClusterId',
    <String, dynamic>{
      'clusterId': clusterId,
    },
  );
}

Future<String?> getClusterId() async {
  return await _globalChannel.invokeMethod("getClusterId");
}
